@@ -21,11 +21,11 @@ pub async fn get_paste(req: Request<State>) -> tide::Result<Response> {
     let state = req.state();
     let pool = state.pool.lock().await;
     let mut cache = state.cache.lock().await;
-    let cache_key = id.parse::<i64>().unwrap();
+    let cache_key = id.to_string();
 
     let mut response: Response;
 
-    let paste: Option<Paste> = pool.fetch_by_column("id", &id.to_string()).await.unwrap();
+    let paste: Option<Paste> = pool.fetch_by_column("id", &id).await.unwrap();
 
     match paste {
         Some(paste) => {
@@ -50,7 +50,7 @@ pub async fn get_paste(req: Request<State>) -> tide::Result<Response> {
                 let ts = ThemeSet::load_defaults();
 
                 html_content = highlighted_html_for_string(s, &ss, syntax, &ts.themes[THEME]);
-                let _ = cache.put_with_weight(cache_key, html_content.clone());
+                let _ = cache.put_with_weight(cache_key.to_string(), html_content.clone());
             }
 
             response = GetPasteTemplate {
